"use strict";
var editorconfig = require("editorconfig");
var emitBaseDirWarning = false;
function makeFormatCodeOptions(fileName, opts, formatOptions) {
    if (opts.verbose && opts.baseDir && !emitBaseDirWarning) {
        console.log("editorconfig is not supported baseDir options");
        emitBaseDirWarning = true;
    }
    return editorconfig
        .parse(fileName)
        .then(function (config) {
        if (Object.keys(config).length === 0) {
            return formatOptions;
        }
        if (opts.verbose) {
            console.log("editorconfig: \n" + "file: " + fileName + "\n" + JSON.stringify(config, null, 2));
        }
        if (config.indent_style === "tab") {
            formatOptions.ConvertTabsToSpaces = false;
        }
        else if (typeof config.indent_size === "number") {
            formatOptions.ConvertTabsToSpaces = true;
            formatOptions.IndentSize = config.indent_size;
        }
        if (config.end_of_line === "lf") {
            formatOptions.NewLineCharacter = "\n";
        }
        else if (config.end_of_line === "cr") {
            formatOptions.NewLineCharacter = "\r";
        }
        else if (config.end_of_line === "crlf") {
            formatOptions.NewLineCharacter = "\r\n";
        }
        return formatOptions;
    });
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = makeFormatCodeOptions;
function postProcess(fileName, formattedCode, opts, _formatOptions) {
    if (opts.verbose && opts.baseDir && !emitBaseDirWarning) {
        console.log("editorconfig is not supported baseDir options");
        emitBaseDirWarning = true;
    }
    return editorconfig
        .parse(fileName)
        .then(function (config) {
        if (config.insert_final_newline && !/\n$/.test(formattedCode)) {
            formattedCode += "\n";
        }
        return formattedCode;
    });
}
exports.postProcess = postProcess;
//# sourceMappingURL=editorconfig.js.map